
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;<--OGI-->;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                        ;;
;;             Center for Spoken Language Understanding                   ;;
;;        Oregon Graduate Institute of Science & Technology               ;;
;;                         Portland, OR USA                               ;;
;;                        Copyright (c) 1999                              ;;
;;                                                                        ;;
;;      This module is not part of the CSTR/University of Edinburgh       ;;
;;               release of the Festival TTS system.                      ;;
;;                                                                        ;;
;;  In addition to any conditions disclaimers below, please see the file  ;;
;;  "license_ogi_tts.txt" distributed with this software for information  ;;
;;  on usage and redistribution, and for a DISCLAIMER OF ALL WARRANTIES.  ;;
;;                                                                        ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;<--OGI-->;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Set up diphone voice
;;;  AS diphones: male American English collected May 1997 by OGI

;; load unit selection routine
(set! as_diphone_dir (cdr (assoc 'as_diphone voice-locations)))
(set! load-path (cons (path-append as_diphone_dir "festvox") load-path))

(require 'ogi_configure_voice)
(require 'ogi_as_unitsel)
;(require 'ogi_unitsel_cart)
;(require 'ogi_ntt_cart_tree)
;(set! ogi_unitsel_cart_tree ogi_ntt_cart_tree)
;(require 'as_diphone_lex_addenda)
;(as_diphone_lex_addenda)

;; select voice
;; this defines all the modules to use when synthesizing text using the current voice
(define (voice_as_diphone)
  "(voice_as_diphone)
  Set up the current voice to be an American female AS using the as diphone set."
 
  ;; set target average pitch and variation
  (set! as_f0_mean 200)
  (set! as_f0_std 19)
  (set! FP_F0 200)

  ;; set unit selection method
  (set! OGI_unitsel as_OGI_di_unitsel)
;  (set! OGI_unitsel ntt_OGI_di_cart_unitsel)

  
  ;; use the grouped file by default
  (set! ogi_grouped_or_ungrouped 'grouped)
  
  ;; use resLPC or sinLPC signal processing
  (set! ogi_resORsinLPC 'resLPC)
  
  ;; configure voice using defaults 
  (ogi_configure_voice 'as)

  ;; overwrite defaults here:
  
  ;; diphone unit selection fallbacks
  ;; diphone unit selection fallbacks
  (set! ogi_di_alt_L '((m= (m)) (n= (n)) (l= (l)) (h (pau)) 
		       (j (i:)) (dx (t d)) (& (^))
		       (k>9r (k)) (k>w (k)) (k>l (k))
		       (p>9r (p)) (p>w (p)) (p>l (p))
		       (t>9r (t)) (t>w (t)) (t>l (t)) (t>9r<s (t>9r t<s t)) 
		       (p>9r<s (p>9r p)) (t<s (t)) (pau (?))))

  (set! ogi_di_alt_R '((m= (m)) (n= (n)) (l= (l)) (h (pau)) 
		       (j (i:)) (dx (t d)) (& (^))
		       (k>9r (k)) (k>w (k)) (k>l (k))
		       (p>9r (p)) (p>w (p)) (p>l (p))
		       (t>9r (t)) (t>w (t)) (t>l (t)) 
		       (t>9r<s (t>9r t<s t)) (p>9r<s (p>9r p))
		       (t<s (t))))

  (set! ogi_di_default "pau-h")

  ;; phrase curve values
  (set! AccentMaxStart 65);50
  (set! AccentMaxMid 40);30
  (set! AccentMaxEnd 50);15
  (set! AccentQuestion 80)
  (set! AccentComma2 20) ;; 40
  (set! AccentComma3 10) ;; 15
  (set! AccentComma4 30) ;; 60
  (set! PhraseStart 220);130
  (set! PhraseMid 180);110
  (set! PhraseEnd 140);90

  ;; reslpc ungrouped analysis
  ;; define analysis parameters for OGIresLPC module
  (set! voicename 'as)
  (if (string-equal ogi_grouped_or_ungrouped "grouped")
    (set! ogi_resLPC_analysis_params (list
      (list 'dbname voice_dirname)
      (list 'groupfile (path-append ogi_diphone_dir "group" (string-append voicename "_diphone_resLPC.group")))
    '(data_type "resLPC")
      '(access_mode "ondemand")
    ))
    ;; else if ungrouped
    (set! ogi_resLPC_analysis_params (list
        (list 'dbname voice_dirname)
        (list 'unitdic_file (path-append ogi_diphone_dir "ungrouped" "unittable.ms"))
;        (list 'gain_file (path-append ogi_diphone_dir "festvox" "gain.dat"))
        '(phoneset "worldbet")  
        (list 'base_dir  (path-append ogi_diphone_dir "ungrouped/"))
        '(lpc_dir "lpc/")
        '(lpc_ext ".lsf")
        '(exc_dir "lpc/")
        '(exc_ext ".res")
        '(pm_dir "pm/")
        '(pm_ext ".pmv")
        '(data_type "resLPC")
        '(access_mode "ondemand")
        '(samp_freq 22050)
        '(sig_band 0.010) 
        '(isCompressed "Y") ;; if "Y", compress when saving group file
        '(preemph 0.85) ;; 0.96 default
	'(deemphasis 0.99)      ;; opposite of preemphasis (lowpass filter)
  
    ))
  )

  ;; analysis parameters for OGIsinLPC module
  (set! ogi_sinLPC_analysis_params  
    (list
      (list 'voicename voice_dirname)
      (list 'groupfile (path-append ogi_diphone_dir "group" (string-append voicename "_diphone_sinLPC.group")))
      '(access_mode "ondemand")  ; ondemand OR load_all
      '(useCompressed 0)  ;; compress groupfile if one is created.  Reduces size by 30%, but mulaw artifacts in nasals.  
      '(doSinAnalysis 1)
    )
  )
  (if (string-equal ogi_grouped_or_ungrouped "grouped")
    (set! ogi_sinLPC_analysis_params 
      (append ogi_sinLPC_analysis_params (list '(useGrouped 1)))
    )
    ;; else if ungrouped
    (set! ogi_sinLPC_analysis_params (append ogi_sinLPC_analysis_params 
      (list
        '(useGrouped 0)
        (list 'unittable_file (path-append ogi_diphone_dir "ungrouped" "unittable.ms"))
        (list 'pmdir (path-append ogi_diphone_dir "ungrouped" "pm"))
        (list 'wavdir (path-append ogi_diphone_dir "ungrouped" "wav"))
        (list 'sinlpcdir (path-append ogi_diphone_dir "ungrouped" "sinlpc"))
        '(sinlpc_save_format "est_ascii")  ;; other option: est_binary
        '(Fs 16000)         ;; sampling frequency of database units
        '(Fvox 4000)        ;; compute sinusoidal params only in 0-Fvox frequency band
        '(vuv_filt          ;; result of Matlab  fir1(6,2*4000/22050) 
          ((-0.002650233384 0.042637343726 0.253502315847 0.413021147621 0.253502315847 0.042637343726 -0.002650233384)
           (1.0)))
        '(lpcorder 14)      ;; lpcorder (for mel warped spectrum)
        '(pre-emph .95)
        '(show_chunk_pms 0)
      )
    ))
  )

;  (set! after_synth_hooks 
;	(lambda (utt) 
;	  (utt.wave.rescale utt 2.5)))


  ;; initialize signal processing module 
  (initialize_OGIsynth)
  
)

;; proclaim voice
(proclaim_voice
 'as_diphone
 '((language english)
   (gender female)
   (dialect american)
   (description
    "This voice provides an American English female voice using a
     residual excited or sinusoidal LPC diphone synthesis module created at
     OGI.  It uses a lexicon compiled from MOBY and CMU lexicons, and
     other trained modules used by CSTR voices.")
   (samplerate 22050)))

;; comment this out if you want changes in this file to take effect without restarting Festival
(provide 'as_diphone)   

